##  Fact Sheet Relations
Event | Description
---|---
RELATION_CREATED | A new relation between fact sheets is created.
RELATION_UPDATED | A relation between fact sheets is updated.
RELATION_ARCHIVED | A relation between fact sheets is archived.
RELATION_DELETED | A relation between fact sheets is deleted. Deletion occurs when a fact sheet type is deleted from the meta model configuration or the retention period for an archived fact sheet ends.
RELATION_SWITCH | Only the target fact sheet within a relation changed.


